@@ -9,9 +9,11 @@ from typing import Optional
 
 import boto3
 from mypy_boto3_ssm import SSMClient
-from sqlalchemy.future.engine import Connection
+from sqlalchemy.future.engine import Connection, create_engine
 from sqlmodel import text
 
+from ata_db_models.models import SQLModel
+
 
 class Privilege(str, Enum):
     """
@@ -100,9 +102,12 @@ def generate_password() -> str:
     return password
 
 
-def create_user(conn: Connection, username: str) -> str:
+def create_user(conn: Connection, username: str, bypassrls: bool = False) -> str:
     pw = generate_password()
-    statement = text(f"CREATE USER {username} WITH PASSWORD :password")
+    rls_flag = ""
+    if bypassrls:
+        rls_flag = " BYPASSRLS"
+    statement = text(f"CREATE USER {username} WITH PASSWORD :password{rls_flag}")
     conn.execute(statement, {"password": pw})
     return pw
 
@@ -124,7 +129,9 @@ def enable_row_level_security(conn: Connection, table: str, target_column: str,
     conn.execute(s1)
     random_postfix = "%06x" % random.randrange(16**6)
     policy_name = f"{table}_{role}_{random_postfix}"
-    s2 = text(f"CREATE POLICY {policy_name} ON {table} TO {role} USING (current_user LIKE '%' || {target_column} || '%')")
+    s2 = text(
+        f"CREATE POLICY {policy_name} ON {table} TO {role} USING (current_user ~ REPLACE({target_column}, '-', '_'))"
+    )
     conn.execute(s2)
 
 
@@ -159,7 +166,7 @@ def get_conn_string(db_name: Optional[str] = None) -> str:
     if not db_name:
         # if no db_name is passed, we assume it is for the default db. This is assumed to be "default"
         # unless indicated otherwise via this DB_NAME env var
-        db_name = os.getenv("DB_NAME", "default")
+        db_name = os.getenv("DB_NAME", "postgres")
 
     return f"postgresql://{user}:{password}@{host}:{port}/{db_name}"
 
@@ -170,3 +177,43 @@ def get_ssm_client() -> Optional[SSMClient]:
         return boto3.client("ssm")
     else:
         return None
+
+
+def pre_table_initialization(
+    stage: Stage, components: list[Component], partner_names: list[Partner], create_dbs: bool = True
+) -> None:
+    engine = create_engine(get_conn_string())
+
+    with engine.connect() as conn:
+        if create_dbs:
+            create_database(conn, db_name=stage)
+        for component in components:
+            role = f"{stage}_{component.name}"
+            create_role(conn, role=role)
+            usernames = [f"{stage}_{component.name}_{partner_name}" for partner_name in partner_names]
+            create_users(conn, stage=stage, component=component, partner_names=partner_names)
+            assign_role(conn, role=role, usernames=usernames)
+        conn.commit()
+
+
+def initialize_tables(stage: Stage) -> None:
+    engine = create_engine(get_conn_string(db_name=stage))
+    SQLModel.metadata.create_all(engine)
+
+
+def post_table_initialization(stage: Stage, components: list[Component]) -> None:
+    engine = create_engine(get_conn_string(db_name=stage))
+
+    with engine.connect() as conn:
+        for component in components:
+            for grant in component.grants:
+                for table in grant.tables:
+                    grant_privileges(
+                        conn, user_or_role=f"{stage}_{component.name}", table=table, privileges=grant.privileges
+                    )
+            for policy in component.policies:
+                enable_row_level_security(
+                    conn, table=policy.table, target_column=policy.user_column, role=f"{stage}_{component.name}"
+                )
+
+        conn.commit()
