@@ -1,4 +1,5 @@
 from datetime import datetime
+from enum import Enum
 from typing import Optional, Union
 from uuid import UUID
 
@@ -6,6 +7,15 @@ from pydantic import HttpUrl
 from sqlmodel import JSON, Column, Field, SQLModel, String
 
 
+class RefrMedium(str, Enum):
+    email = "email"
+    internal = "internal"
+    paid = "paid"
+    search = "search"
+    social = "social"
+    unknown = "unknown"
+
+
 class Event(SQLModel, table=True):
     # TODO make enum
     site_name: str = Field(primary_key=True)
@@ -27,10 +37,7 @@ class Event(SQLModel, table=True):
     # Name of event. Can be "page_view", "page_ping", "focus_form", "change_form", "submit_form"
     # TODO make enum
     event_name: str
-    # User ID set by Snowplow using 3rd party cookie
-    network_userid: UUID
     # [STR, CATEGORICAL if needed] Path to page, e.g., /event-directory/ in https://dallasfreepress.com/event-directory/
-    # TODO make regex validation
     page_urlpath: str
     # URL of the referrer
     page_referrer: HttpUrl = Field(sa_column=Column(String))
@@ -38,18 +45,24 @@ class Event(SQLModel, table=True):
     pp_yoffset_max: Optional[float] = None
     # Type of referer. Can be "social", "search", "internal", "unknown", "email"
     # (read: https://docs.snowplow.io/docs/enriching-your-data/available-enrichments/referrer-parser-enrichment/)
-    # TODO consider making this an enum
-    refr_medium: Optional[str] = None
+    refr_medium: Optional[RefrMedium] = None
     # Name of referer if recognised, e.g., "Google" or "Bing"
     refr_source: Optional[str] = None
-    # Data/attributes of HTML input and its form in JSON format. Only present if event_name == "change_form"
-    # (read: https://github.com/snowplow/iglu-central/blob/master/schemas/com.snowplowanalytics.snowplow/change_form/jsonschema/1-0-0)
-    unstruct_event_com_snowplowanalytics_snowplow_change_form_1: Optional[Union[list, dict]] = Field(sa_column=Column(JSON))  # type: ignore
-    # Data/attributes of HTML input and its form in JSON format. Only present if event_name == "focus_form"
-    # (read: https://github.com/snowplow/iglu-central/blob/master/schemas/com.snowplowanalytics.snowplow/focus_form/jsonschema/1-0-0)
-    unstruct_event_com_snowplowanalytics_snowplow_focus_form_1: Optional[Union[list, dict]] = Field(sa_column=Column(JSON))  # type: ignore
     # Data/attributes of HTML form and all its inputs in JSON format. Only present if event_name == "submit_form"
     # (read: https://github.com/snowplow/iglu-central/blob/master/schemas/com.snowplowanalytics.snowplow/submit_form/jsonschema/1-0-0)
     unstruct_event_com_snowplowanalytics_snowplow_submit_form_1: Optional[Union[list, dict]] = Field(sa_column=Column(JSON))  # type: ignore
     # Raw useragent
     useragent: str
+    br_viewheight: Optional[float]
+    br_viewwidth: Optional[float]
+    refr_urlhost: Optional[str]
+    refr_urlpath: Optional[str]
+
+
+class Prescription(SQLModel, table=True):
+    user_id: UUID = Field(primary_key=True)
+    site_name: str = Field(primary_key=True)
+    prescribe: bool
+    last_updated: datetime
+    # TODO will add this once we have models to work with!
+    # model_id: UUID = Field(foreign_key="model.id")
